class SuccessRespData:
    """[data]"""

    def __init__(self, json: dict) -> None:
        self.file = SuccessRespDataFile(json.get("file"))


class SuccessRespDataFile:
    """[data][file]"""

    def __init__(self, json: dict) -> None:
        self.url = SuccessRespDataFileUrl(json.get("url"))
        self.metadata = SuccessRespDataFileMetadata(json.get("metadata"))


class SuccessRespDataFileUrl:
    """[data][file][url]"""

    def __init__(self, json: dict) -> None:
        self.full = json.get("full")
        self.short = json.get("short")


class SuccessRespDataFileMetadata:
    """[data][file][metadata]"""

    def __init__(self, json: dict) -> None:
        self.id = json.get("id")
        self.name = json.get("name")
        self.size = SuccessRespDataFileMetadataSize(json.get("size"))


class SuccessRespDataFileMetadataSize:
    """[data][file][metadata][size]"""

    def __init__(self, json: dict) -> None:
        self.bytes = json.get("bytes")
        self.readable = json.get("readable")


class ErrorResp:
    """[error]"""

    def __init__(self, json: dict) -> None:
        self.message = json.get("message")
        self.type = json.get("type")
        self.code = json.get("code")


import pytest

from anonfiles import AnonFiles


@pytest.fixture()
def anonfile():
    """Return AnonFiles object."""
    return AnonFiles()


# NOTE: file id used really exists
@pytest.mark.parametrize(
    "id, status",
    [("d9e3l3ofub", True), ("justnonexistentid", False)],
)
def test_info(anonfile, id, status):
    info = anonfile.info(id)
    assert info.status == status


from __future__ import annotations
from .resp import ErrorResp, SuccessRespData
import requests


class AnonFiles:
    API_URL = "https://api.anonfiles.com"

    def __init__(self, token: str = None) -> None:
        """
        token: user api token
        """

        # URL Docs: https://anonfiles.com/docs/api

        self.__api_upload_url = self.API_URL + "/upload"  # UPLOAD api
        if token:
            self.__api_upload_url += f"?token={token}"
        self.__info_url = self.API_URL + "/v2/file/{id}/info"  # INFO api

    def upload(self, file: str) -> AnonSuccessResponse | AnonErrorResponse:
        """
        Upload file.

        file: (string) path of the file to upload
        """

        # TODO: implement multiple files

        # request
        with open(file, "rb") as f:
            r = requests.post(self.__api_upload_url, files={"file": f})

        # error response
        if not r.json()["status"]:
            return AnonErrorResponse(r.json())

        # success response
        return AnonSuccessResponse(r.json())

    def info(self, id: str) -> AnonSuccessResponse | AnonErrorResponse:
        """
        Grab info about a file.

        id: (string) file id
        """
        # TODO: implement multiple id

        # request
        r = requests.get(self.__info_url.format(id=id))

        # error response
        if not r.ok:
            return AnonErrorResponse(r.json())

        # success response
        return AnonSuccessResponse(r.json())


class AnonSuccessResponse:
    def __init__(self, json: dict) -> None:
        self.status = json.get("status")
        self.data = SuccessRespData(json.get("data"))


class AnonErrorResponse:
    def __init__(self, json: dict) -> None:
        self.status = json.get("status")
        self.error = ErrorResp(json.get("error"))


from setuptools import setup
import pathlib

README = (pathlib.Path(__file__).parent / "README.md").read_text()

setup(
    name="anonfiles-py",
    version="0.1.0",
    description="Simple AnonFiles.com API Wrapper",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/TheBoringDude/anonfiles.py",
    author="TheBoringDude",
    author_email="iamcoderx@gmail.com",
    license="MIT",
    project_urls={
        "Bug Tracker": "https://github.com/TheBoringDude/anonfiles.py/issues"
    },
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    packages=["anonfiles"],
    include_package_data=True,
    install_requires=["requests"],
)